.. module:: numpy.testing.overrides

Support for testing overrides (:mod:`numpy.testing.overrides`)
==============================================================

.. currentmodule:: numpy.testing.overrides

Support for testing custom array container implementations.

Utility Functions
-----------------
.. autosummary::
   :toctree: generated/

   allows_array_function_override
   allows_array_ufunc_override
   get_overridable_numpy_ufuncs
   get_overridable_numpy_array_functions
